Porto
=====

Porto provides an unified and simplified access to various online stamp services. Currently supported are the following services:

* Deutsche Post: Internetmarke (Germany)

Installation
------------

The simplest way to install Porto is using pip:

..

  pip install porto

Additionally, you can checkout the source code:

..

  git clone https://edugit.org/hansegucker/porto

License
-------

Copyright 2022 Jonathan Weth <dev@jonathanweth.de>

Licensed under the MIT License (see LICENSE for more information).
